Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(522)

Unified Diff: webkit/glue/webview_impl.h

Issue 149620: Use WebWidget from the WebKit API. This change also makes... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/glue/webview_delegate.h ('k') | webkit/glue/webview_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/webview_impl.h
===================================================================
--- webkit/glue/webview_impl.h (revision 20851)
+++ webkit/glue/webview_impl.h (working copy)
@@ -49,9 +49,27 @@
class WebViewImpl : public WebView, public base::RefCounted<WebViewImpl> {
public:
- // WebView
+ // WebWidget methods:
+ virtual void close();
+ virtual WebKit::WebSize size() { return size_; }
+ virtual void resize(const WebKit::WebSize& new_size);
+ virtual void layout();
+ virtual void paint(WebKit::WebCanvas* canvas,
+ const WebKit::WebRect& rect);
+ virtual bool handleInputEvent(const WebKit::WebInputEvent& input_event);
+ virtual void mouseCaptureLost();
+ virtual void setFocus(bool enable);
+ virtual bool handleCompositionEvent(WebKit::WebCompositionCommand command,
+ int cursor_position,
+ int target_start,
+ int target_end,
+ const WebKit::WebString& text);
+ virtual bool queryCompositionStatus(bool* enabled,
+ WebKit::WebRect* caret_rect);
+ virtual void setTextDirection(WebKit::WebTextDirection direction);
+
+ // WebView methods:
virtual bool ShouldClose();
- virtual void Close();
virtual WebViewDelegate* GetDelegate();
virtual void SetDelegate(WebViewDelegate*);
virtual void SetUseEditorDelegate(bool value);
@@ -62,22 +80,7 @@
virtual WebFrame* GetFrameWithName(const std::wstring& name);
virtual WebFrame* GetPreviousFrameBefore(WebFrame* frame, bool wrap);
virtual WebFrame* GetNextFrameAfter(WebFrame* frame, bool wrap);
- virtual void Resize(const WebKit::WebSize& new_size);
- virtual WebKit::WebSize GetSize() { return size(); }
- virtual void Layout();
- virtual void Paint(skia::PlatformCanvas* canvas, const WebKit::WebRect& rect);
- virtual bool HandleInputEvent(const WebKit::WebInputEvent* input_event);
- virtual void MouseCaptureLost();
- virtual void SetFocus(bool enable);
virtual void ClearFocusedNode();
- virtual bool ImeSetComposition(int string_type,
- int cursor_position,
- int target_start,
- int target_end,
- const std::wstring& ime_string);
- virtual bool ImeUpdateStatus(bool* enable_ime,
- WebKit::WebRect* caret_rect);
- virtual void SetTextDirection(WebTextDirection direction);
virtual void StopLoading();
virtual void SetBackForwardListSize(int size);
virtual void SetInitialFocus(bool reverse);
@@ -130,8 +133,6 @@
// WebViewImpl
- const WebKit::WebSize& size() const { return size_; }
-
const WebKit::WebPoint& last_mouse_down_point() const {
return last_mouse_down_point_;
}
@@ -196,11 +197,11 @@
}
// Set the disposition for how this webview is to be initially shown.
- void set_window_open_disposition(WindowOpenDisposition disp) {
- window_open_disposition_ = disp;
+ void set_initial_navigation_policy(WebKit::WebNavigationPolicy policy) {
+ initial_navigation_policy_ = policy;
}
- WindowOpenDisposition window_open_disposition() const {
- return window_open_disposition_;
+ WebKit::WebNavigationPolicy initial_navigation_policy() const {
+ return initial_navigation_policy_;
}
// Start a system drag and drop operation.
@@ -303,8 +304,8 @@
// this behavior by setting this flag if the keyDown was handled.
bool suppress_next_keypress_event_;
- // The disposition for how this webview is to be initially shown.
- WindowOpenDisposition window_open_disposition_;
+ // The policy for how this webview is to be initially shown.
+ WebKit::WebNavigationPolicy initial_navigation_policy_;
// Represents whether or not this object should process incoming IME events.
bool ime_accept_events_;
« no previous file with comments | « webkit/glue/webview_delegate.h ('k') | webkit/glue/webview_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698